@@ -1,9 +1,8 @@
 from datetime import datetime
-from typing import Optional, Union
+from typing import Union
 
 from PyYandexLMS.models.base.main import BaseModel
 from PyYandexLMS.models.lesson import BaseLesson
-from PyYandexLMS.models.solution import BaseSolution
 from PyYandexLMS.models.tag import Tag
 
 
@@ -14,7 +13,6 @@ class BaseTask(BaseModel):
     tag: Tag
     score_max: int
     lesson: BaseLesson
-    solution: Optional[BaseSolution]
     deadline: Union[datetime, None]
     is_contest_integrated: bool
     has_manual_check: bool
