@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Optional
+from typing import Optional, Union
 
 from PyYandexLMS.models.base.main import BaseModel
 
@@ -11,6 +11,6 @@ class File(BaseModel):
     mime_type: str
     encoding: str
     size: int
-    run_id: str
+    run_id: Union[str, None]
     added_time: datetime
     source_code: Optional[str]
